@@ -3,6 +3,6 @@
 export const index = 28;
 let component_cache;
 export const component = async () => component_cache ??= (await import('../entries/pages/(app)/workspace/_page.svelte.js')).default;
-export const imports = ["_app/immutable/nodes/28.CvssLpFK.js","_app/immutable/chunks/JdJvpXsd.js","_app/immutable/chunks/IHki7fMi.js","_app/immutable/chunks/B1PwnIfG.js","_app/immutable/chunks/C1Orkscy.js"];
+export const imports = ["_app/immutable/nodes/28.CDXswR8q.js","_app/immutable/chunks/BsAB9Z30.js","_app/immutable/chunks/IHki7fMi.js","_app/immutable/chunks/BY-rXZ0_.js","_app/immutable/chunks/BrBP5fsK.js"];
 export const stylesheets = [];
 export const fonts = [];
