@@ -3,6 +3,6 @@
 export const index = 45;
 let component_cache;
 export const component = async () => component_cache ??= (await import('../entries/pages/watch/_page.svelte.js')).default;
-export const imports = ["_app/immutable/nodes/45.CF_YFqWR.js","_app/immutable/chunks/JdJvpXsd.js","_app/immutable/chunks/IHki7fMi.js","_app/immutable/chunks/B1PwnIfG.js"];
+export const imports = ["_app/immutable/nodes/45.Dqo1FTkF.js","_app/immutable/chunks/BsAB9Z30.js","_app/immutable/chunks/IHki7fMi.js","_app/immutable/chunks/BY-rXZ0_.js"];
 export const stylesheets = [];
 export const fonts = [];
